pub struct Db { /* private fields */ }Expand description
Db container that uses a connection pool to hand out connections
Uses an deadpool connection pool to manage multiple established connections.
Implementations
Sourceimpl Db
impl Db
Sourcepub fn connect(db_settings: &Database) -> Result<Self>
pub fn connect(db_settings: &Database) -> Result<Self>
Creates a new Db instance from the specified database settings.
Sourcepub fn connect_url(db_url: &str, max_conns: u32) -> Result<Self>
pub fn connect_url(db_url: &str, max_conns: u32) -> Result<Self>
Creates a new Db instance from the specified database url.
Sourcepub fn set_metrics(&mut self, metrics: Arc<DatabaseMetrics>)
pub fn set_metrics(&mut self, metrics: Arc<DatabaseMetrics>)
Set the metrics to use for this database pool
Sourcepub async fn get_conn(&self) -> Result<DbConnection>
pub async fn get_conn(&self) -> Result<DbConnection>
Returns an established connection from the connection pool